Dependencies for testing OME Ansible roles with Molecule
========================================================

.. image:: https://github.com/ome/ome-ansible-molecule/workflows/PyPI/badge.svg
   :target: https://github.com/ome/ome-ansible-molecule/actions/

.. image:: https://badge.fury.io/py/ome-ansible-molecule.svg
    :target: https://badge.fury.io/py/ome-ansible-molecule

A meta-package that installs common dependencies required to test most
`OME Ansible Galaxy roles <https://galaxy.ansible.com/ome/>`_.

See https://github.com/ome/action-ome-ansible-molecule for an example of
GitHub action consuming this package in a GitHub workflow
